@@ -4,10 +4,20 @@
   >>> from zope.annotation.attribute import AttributeAnnotations
   >>> component.provideAdapter(AttributeAnnotations)
 
+If you query an annotation that does exists you get None:
+
+  >>> manfred = Mammoth()
+  >>> grok.queryAnnotation(manfred, IBranding) is None
+  True
+
+If you query an annotation with an interface that does not match you get None:
+
+  >>> grok.queryAnnotation(manfred, None) is None
+  True
+
 We can adapt a model to an annotation interface and obtain a
 persistent annotation storage:
 
-  >>> manfred = Mammoth()
   >>> branding = IBranding(manfred)
   >>> branding.addBrand('mine')
   >>> branding.addBrand('yours')
@@ -31,12 +41,40 @@ Regetting the adapter will yield the same annotation storage:
   >>> brands
   ['mine', 'yours']
 
+Using getAnnotation will work too now:
+
+  >>> sorted(grok.queryAnnotation(manfred, IBranding).getBrands())
+  ['mine', 'yours']
+  >>>
+
+And you can delete an annotation:
+
+  >>> grok.deleteAnnotation(manfred, IBranding)
+  True
+
+If you try to delete it again, you get False:
+
+  >>> grok.deleteAnnotation(manfred, IBranding)
+  False
+
+If you try to query for a non existing annotation you get None:
+
+  >>> grok.queryAnnotation(manfred, IBranding) is None
+  True
+
+If you want to delete a non-matching annotation you get False:
+
+  >>> grok.deleteAnnotation(manfred, None)
+  False
+
+
 """
 
 import grokcore.annotation as grok
 from zope import interface
 from BTrees.OOBTree import OOTreeSet
 
+
 class Mammoth(grok.Model):
     pass
 
@@ -48,8 +86,8 @@ class IBranding(interface.Interface):
     def getBrands():
         """Return a list of brands."""
 
+@grok.implementer(IBranding)
 class Branding(grok.Annotation):
-    grok.implements(IBranding)
 
     def __init__(self):
         self._brands = OOTreeSet()
