@@ -5,10 +5,8 @@ be registered for.  Ambiguities lead to errors:
 
   >>> grok.testing.grok(__name__)
   Traceback (most recent call last):
-  GrokError: <class
-  'grokcore.annotation.tests.annotation.implementsmany.MammothAnnotations'> is
-  implementing more than one interface (use grok.provides to specify
-  which one to use).
+  ...
+  martian.error.GrokError: <class 'grokcore.annotation.tests.annotation.implementsmany.MammothAnnotations'> is implementing more than one interface (use grok.provides to specify which one to use).
 """
 
 import grokcore.annotation as grok
@@ -23,5 +21,6 @@ class IOneInterface(interface.Interface):
 class IAnotherInterface(interface.Interface):
     pass
 
+@grok.implementer(IOneInterface, IAnotherInterface)
 class MammothAnnotations(grok.Annotation):
-    grok.implements(IOneInterface, IAnotherInterface)
+    pass
