@@ -21,17 +21,20 @@ It can then be looked up only using that one interface:
 
 import grokcore.annotation as grok
 from zope import interface
-from BTrees.OOBTree import OOTreeSet
+
 
 class Mammoth(grok.Model):
     pass
 
+
 class IOneInterface(interface.Interface):
     pass
 
+
 class IAnotherOne(interface.Interface):
     pass
 
+
+@grok.implementer(IOneInterface, IAnotherOne)
 class MammothAnnotation(grok.Annotation):
-    grok.implements(IOneInterface, IAnotherOne)
     grok.provides(IOneInterface)
